%-------------------------------------------------------------------------------
% Generates figure 2 in [1]. 
%
% USE: [Qs,dBs] = figure_2(dB_max,dB_min,dB_step)
%
% INPUT:
%      dB_max = maximum dB value
%      dB_min = min dB value
%      dB_step = step value for dB vector
% 
% OUTPUT:
%      Qs = 6xN matrix for values of Q for 6 different signal types
%
% EXAMPLE:
%      Qs=performance_Q(10,30,10);
%      plot_Qs(Qs);
%
%
% Used to plot Qs values for figure 2 in [1].  If you use this code in
% your research or publications, please reference [1].
%
% [1] J.M. O' Toole, M. Mesbah, B. Boashash, "Accurate and efficient
% implementation of the time-frequency matched filter", IET Signal
% Process., Special Issue of Time-Frequency Approach to Radar
% Detection, Imaging, and Classification, submitted for publication,
% 2009

%
%   Copyright (c) 2009, John M. O' Toole, The University of Queensland
%   All rights reserved.
%
%  Redistribution and use in source and binary forms, with or without
%  modification, are permitted provided that the following
%  conditions are met:
%      * Redistributions of source code must retain the above
%        copyright notice, this list of conditions and the following
%        disclaimer.
%      * Redistributions in binary form must reproduce the above
%        copyright notice, this list of conditions and the following
%        disclaimer in the documentation and/or other materials
%        provided with the distribution.
%      * Neither the name of the <organization> nor the names of its
%        contributors may be used to endorse or promote products
%        derived from this software without specific prior written
%        permission.
%  
%  THIS SOFTWARE IS PROVIDED BY JOHN M. O' TOOLE ''AS IS'' AND ANY
%  EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
%  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
%  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL JOHN M. O' TOOLE BE
%  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
%  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
%  OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
%  BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
%  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
%  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
%  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
%  DAMAGE.
%
%-------------------------------------------------------------------------------

function [Qs,dBs]=figure_2(dB_max,dB_min,dB_step)
if(nargin<1) dB_max=10; end
if(nargin<2) dB_min=-30; end
if(nargin<3) dB_step=2; end

dBs=linspace(dB_min,dB_max,round(abs(dB_max-dB_step-dB_min)/dB_step));
L=length(dBs);

Qs=performance_Q(dB_max,dB_min,dB_step);
plot_Qs(Qs,dBs);



