%-------------------------------------------------------------------------------
% Get discrete analytic signal.  See [1] for details.
%
% USE: z=get_analytic(s)
%
% INPUT:
%      s = real-valued signal
%
% OUTPUT:
%      z = complex-valued analytic signal
%
% EXAMPLE
%      N=64;  f=0.1; N2=2*N;
%      s=cos( 2*pi*f.*(0:N-1));     
%      z=get_analytic(s);
%      plot(1:N2,real(z),1:N2,imag(z));
%      legend('real','imaginary');
%
% 
% If you use this code in your research or publications, please
% reference [1].
%
%
% [1] J.M. O' Toole, M. Mesbah, and B. Boashash, "A New Discrete
% Analytic Signal for Reducing Aliasing in the Discrete Wigner-Ville
% Distribution", IEEE Trans. Signal Proc., vol. 56, no. 11,
% pp. 5427-5434, Nov. 2008.

%
%   Copyright (c) 2009, John M. O' Toole, The University of Queensland
%   All rights reserved.
%
%  Redistribution and use in source and binary forms, with or without
%  modification, are permitted provided that the following
%  conditions are met:
%      * Redistributions of source code must retain the above
%        copyright notice, this list of conditions and the following
%        disclaimer.
%      * Redistributions in binary form must reproduce the above
%        copyright notice, this list of conditions and the following
%        disclaimer in the documentation and/or other materials
%        provided with the distribution.
%      * Neither the name of the <organization> nor the names of its
%        contributors may be used to endorse or promote products
%        derived from this software without specific prior written
%        permission.
%  
%  THIS SOFTWARE IS PROVIDED BY JOHN M. O' TOOLE ''AS IS'' AND ANY
%  EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
%  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
%  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL JOHN M. O' TOOLE BE
%  LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
%  CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT
%  OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
%  BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
%  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
%  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
%  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
%  DAMAGE.
%
%-------------------------------------------------------------------------------
function z=get_analytic(s1);
s1=real(s1);
N=length(s1); N2=2*N;

% 1. zero-pad N-point signal to 2N
s1=[s1(:); zeros(N,1)];
S1=fft(s1);

% 2. Get analytic signal of 2N-point signal
H=zeros(N2,1); 
H([1 N+1])=1;
H(2:N)=2;
z_cb=ifft(S1.*H);


% 3. Force the second half of the time-domain signal to zero.
z=[z_cb(1:N); zeros(N,1)];







